---
name: Bug Report
about: Use this if something isn't working how you think it should or you think you've
  found a bug
title: "[scope] summary of your bug"
labels: state/awaiting-investigation, state/awaiting-triage, type/bug
assignees: ''

---

# Bug Report
<!-- Describe what's wrong in great detail (required). -->

## Steps to reproduce
<!-- Tell us how to reproduce your issue (required). -->
1.
2.
3.

## Expected result
<!-- Tell us what result you were expecting (required). -->

## Actual result
<!-- Tell us what the actual result was (required). -->

## Testcase
<!--
  If possible create an example of your issue via a JSFiddle. 

  How to create an example:
   1. Open the following JSFiddle - https://jsfiddle.net/31d6y7mn
   2. Click "Fork" at the top
   3. Add the minimum required HTML, CSS and JavaScript which reproduces
      your issue
   4. Click "Save" at the top
   5. Copy the URL of your fiddle and link it here
-->

## Screenshot (if possible)
<!--
  If possible include images or gifs of your issue.

  E.g. Incorrect component CSS should include an image of what the
  component looks like.
  
  If your looking for a tool we recommend ShareX - https://github.com/ShareX/ShareX
-->

## Version
<!-- Include the version of the library you are using (required). -->
2.x.x
